==> openshift-model-operator-6.8.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/IngressControllerTuningOptionsBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IngressControllerTuningOptionsBuilder extends IngressControllerTuningOptionsFluent<IngressControllerTuningOptionsBuilder> implements VisitableBuilder<IngressControllerTuningOptions,IngressControllerTuningOptionsBuilder>{
  public IngressControllerTuningOptionsBuilder() {
    this(false);
  }
  public IngressControllerTuningOptionsBuilder(Boolean validationEnabled) {
    this(new IngressControllerTuningOptions(), validationEnabled);
  }
  public IngressControllerTuningOptionsBuilder(IngressControllerTuningOptionsFluent<?> fluent) {
    this(fluent, false);
  }
  public IngressControllerTuningOptionsBuilder(IngressControllerTuningOptionsFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new IngressControllerTuningOptions(), validationEnabled);
  }
  public IngressControllerTuningOptionsBuilder(IngressControllerTuningOptionsFluent<?> fluent,IngressControllerTuningOptions instance) {
    this(fluent, instance, false);
  }
  public IngressControllerTuningOptionsBuilder(IngressControllerTuningOptionsFluent<?> fluent,IngressControllerTuningOptions instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new IngressControllerTuningOptions());

    if (instance != null) {
      fluent.withClientFinTimeout(instance.getClientFinTimeout());
      fluent.withClientTimeout(instance.getClientTimeout());
      fluent.withHeaderBufferBytes(instance.getHeaderBufferBytes());
      fluent.withHeaderBufferMaxRewriteBytes(instance.getHeaderBufferMaxRewriteBytes());
      fluent.withHealthCheckInterval(instance.getHealthCheckInterval());
      fluent.withMaxConnections(instance.getMaxConnections());
      fluent.withReloadInterval(instance.getReloadInterval());
      fluent.withServerFinTimeout(instance.getServerFinTimeout());
      fluent.withServerTimeout(instance.getServerTimeout());
      fluent.withThreadCount(instance.getThreadCount());
      fluent.withTlsInspectDelay(instance.getTlsInspectDelay());
      fluent.withTunnelTimeout(instance.getTunnelTimeout());
      fluent.withClientFinTimeout(instance.getClientFinTimeout());
      fluent.withClientTimeout(instance.getClientTimeout());
      fluent.withHeaderBufferBytes(instance.getHeaderBufferBytes());
      fluent.withHeaderBufferMaxRewriteBytes(instance.getHeaderBufferMaxRewriteBytes());
      fluent.withHealthCheckInterval(instance.getHealthCheckInterval());
      fluent.withMaxConnections(instance.getMaxConnections());
      fluent.withReloadInterval(instance.getReloadInterval());
      fluent.withServerFinTimeout(instance.getServerFinTimeout());
      fluent.withServerTimeout(instance.getServerTimeout());
      fluent.withThreadCount(instance.getThreadCount());
      fluent.withTlsInspectDelay(instance.getTlsInspectDelay());
      fluent.withTunnelTimeout(instance.getTunnelTimeout());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public IngressControllerTuningOptionsBuilder(IngressControllerTuningOptions instance) {
    this(instance,false);
  }
  public IngressControllerTuningOptionsBuilder(IngressControllerTuningOptions instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new IngressControllerTuningOptions());

    if (instance != null) {
      this.withClientFinTimeout(instance.getClientFinTimeout());
      this.withClientTimeout(instance.getClientTimeout());
      this.withHeaderBufferBytes(instance.getHeaderBufferBytes());
      this.withHeaderBufferMaxRewriteBytes(instance.getHeaderBufferMaxRewriteBytes());
      this.withHealthCheckInterval(instance.getHealthCheckInterval());
      this.withMaxConnections(instance.getMaxConnections());
      this.withReloadInterval(instance.getReloadInterval());
      this.withServerFinTimeout(instance.getServerFinTimeout());
      this.withServerTimeout(instance.getServerTimeout());
      this.withThreadCount(instance.getThreadCount());
      this.withTlsInspectDelay(instance.getTlsInspectDelay());
      this.withTunnelTimeout(instance.getTunnelTimeout());
      this.withClientFinTimeout(instance.getClientFinTimeout());
      this.withClientTimeout(instance.getClientTimeout());
      this.withHeaderBufferBytes(instance.getHeaderBufferBytes());
      this.withHeaderBufferMaxRewriteBytes(instance.getHeaderBufferMaxRewriteBytes());
      this.withHealthCheckInterval(instance.getHealthCheckInterval());
      this.withMaxConnections(instance.getMaxConnections());
      this.withReloadInterval(instance.getReloadInterval());
      this.withServerFinTimeout(instance.getServerFinTimeout());
      this.withServerTimeout(instance.getServerTimeout());
      this.withThreadCount(instance.getThreadCount());
      this.withTlsInspectDelay(instance.getTlsInspectDelay());
      this.withTunnelTimeout(instance.getTunnelTimeout());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  IngressControllerTuningOptionsFluent<?> fluent;
  Boolean validationEnabled;
  public IngressControllerTuningOptions build() {
    IngressControllerTuningOptions buildable = new IngressControllerTuningOptions(fluent.getClientFinTimeout(),fluent.getClientTimeout(),fluent.getHeaderBufferBytes(),fluent.getHeaderBufferMaxRewriteBytes(),fluent.getHealthCheckInterval(),fluent.getMaxConnections(),fluent.getReloadInterval(),fluent.getServerFinTimeout(),fluent.getServerTimeout(),fluent.getThreadCount(),fluent.getTlsInspectDelay(),fluent.getTunnelTimeout());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-operator-6.13.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/IngressControllerTuningOptionsBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
public class IngressControllerTuningOptionsBuilder extends IngressControllerTuningOptionsFluent<IngressControllerTuningOptionsBuilder> implements VisitableBuilder<IngressControllerTuningOptions,IngressControllerTuningOptionsBuilder>{
  public IngressControllerTuningOptionsBuilder() {
    this(new IngressControllerTuningOptions());
  }
  
  public IngressControllerTuningOptionsBuilder(IngressControllerTuningOptionsFluent<?> fluent) {
    this(fluent, new IngressControllerTuningOptions());
  }
  
  public IngressControllerTuningOptionsBuilder(IngressControllerTuningOptionsFluent<?> fluent,IngressControllerTuningOptions instance) {
    this.fluent = fluent;
    fluent.copyInstance(instance);
  }
  
  public IngressControllerTuningOptionsBuilder(IngressControllerTuningOptions instance) {
    this.fluent = this;
    this.copyInstance(instance);
  }
  IngressControllerTuningOptionsFluent<?> fluent;
  
  public IngressControllerTuningOptions build() {
    IngressControllerTuningOptions buildable = new IngressControllerTuningOptions(fluent.getClientFinTimeout(),fluent.getClientTimeout(),fluent.getHeaderBufferBytes(),fluent.getHeaderBufferMaxRewriteBytes(),fluent.getHealthCheckInterval(),fluent.getMaxConnections(),fluent.getReloadInterval(),fluent.getServerFinTimeout(),fluent.getServerTimeout(),fluent.getThreadCount(),fluent.getTlsInspectDelay(),fluent.getTunnelTimeout());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  

}
